#
# spec file for package libxls
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libxls
%define lname libxlsreader8
Version:        1.6.3
Release:        1.2
Summary:        Library for Parsing Excel (XLS) Files
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/libxls/libxls
Source:         https://github.com/libxls/libxls/releases/download/v%version/libxls-%version.tar.gz
BuildRequires:  pkg-config

%description
libxls is a C library which can read Excel (xls) files since Excel 97
(the BIFF8 format). libxls cannot write Excel files.

%package -n %lname
Summary:        Library for Parsing Excel (XLS) Files
Group:          System/Libraries

%description -n %lname
libxlsreader is a C library which can read Excel (xls) files since Excel
97 (the BIFF8 format). libxlsreader cannot write Excel files.

%package devel
Summary:        Header files for libxls
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Development files for libxls.

%package tools
Summary:        Utility for parsing Excel (XLS) files
Group:          Productivity/Office/Other
Conflicts:      xls2csv

%description tools
This package contains libxls2csv, a tool which converts an XLS file to
CSV format, more suitable for parsing.

%prep
%autosetup -p1

%build
%configure --disable-static
%make_build

%install
%make_install
rm -f %buildroot/%_libdir/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license LICENSE
%_libdir/*.so.*

%files devel
%_includedir/*
%_libdir/*.so
%_libdir/pkgconfig/*.pc

%files tools
%_bindir/xls2csv
%_mandir/man*/xls2csv*

%changelog
* Thu Dec 26 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.3
  * Fix style record size check on big-endian systems
  * Fix header include in C++ mode
  * Fix buffer overflows when parsing style records
  * Fix infinite loop with self-referencing sectors
- Delete 0001-Fixes-94-possible-null-ptr-deref.patch (merged)
* Mon May 16 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Fixes-94-possible-null-ptr-deref.patch
  [boo#1192323] [CVE-2021-27836]
* Tue Jan 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.2
  * Fix NULL pointer dereferences in the xls2csv tool
    [boo#1179532] [CVE-2020-27819]
* Wed Sep  9 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.1
  * Enabled decoding of non-Unicode character sets in older
    (BIFF5) XLS files.
  * Improved string conversion performance in newer files.
* Tue Aug 25 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.5.3:
  * Allow truncated XLS files
  * Fix long-standing "extra column" bug #73
  * Support for RSTRING records (rich-text cells in older
    BIFF5 files) tidyverse/readxl#611
* Sun Dec  1 2019 Jan Engelhardt <jengelh@inai.de>
- Initial package for openSUSE
